" Vim syntax file
" Language:	none; used to test colors
" Maintainer:	Bram Moolenaar <Bram@vim.org>
" Last Change:	1998 Nov 1

" edit this file, then do ":source %", and check if the colors match

syn clear
syn keyword col_wh_bl	white_on_black
syn keyword col_wh_dblue	white_on_darkblue
syn keyword col_wh_dgreen	white_on_darkgreen
syn keyword col_wh_dcyan	white_on_darkcyan
syn keyword col_wh_dred	white_on_darkred
syn keyword col_wh_dmagenta	white_on_darkmagenta
syn keyword col_wh_brown	white_on_brown
syn keyword col_wh_grey	white_on_grey
syn keyword col_wh_lgrey	white_on_lightgrey
syn keyword col_wh_dgrey	white_on_darkgrey
syn keyword col_wh_blue	white_on_blue
syn keyword col_wh_green	white_on_green
syn keyword col_wh_cyan	white_on_cyan
syn keyword col_wh_red	white_on_red
syn keyword col_wh_magenta	white_on_magenta
syn keyword col_wh_yellow	white_on_yellow
syn keyword col_wh_lblue	white_on_lightblue
syn keyword col_wh_lgreen	white_on_lightgreen
syn keyword col_wh_lcyan	white_on_lightcyan
syn keyword col_wh_lred	white_on_lightred
syn keyword col_wh_lmagenta	white_on_lightmagenta
syn keyword col_wh_wh	white_on_white
syn keyword col_bl_bl	black_on_black
syn keyword col_bl_dblue	black_on_darkblue
syn keyword col_bl_dgreen	black_on_darkgreen
syn keyword col_bl_dcyan	black_on_darkcyan
syn keyword col_bl_dred	black_on_darkred
syn keyword col_bl_dmagenta	black_on_darkmagenta
syn keyword col_bl_brown	black_on_brown
syn keyword col_bl_grey	black_on_grey
syn keyword col_bl_lgrey	black_on_lightgrey
syn keyword col_bl_dgrey	black_on_darkgrey
syn keyword col_bl_blue	black_on_blue
syn keyword col_bl_green	black_on_green
syn keyword col_bl_cyan	black_on_cyan
syn keyword col_bl_red	black_on_red
syn keyword col_bl_magenta	black_on_magenta
syn keyword col_bl_yellow	black_on_yellow
syn keyword col_bl_lblue	black_on_lightblue
syn keyword col_bl_lgreen	black_on_lightgreen
syn keyword col_bl_lcyan	black_on_lightcyan
syn keyword col_bl_lred	black_on_lightred
syn keyword col_bl_lmagenta	black_on_lightmagenta
syn keyword col_bl_wh	black_on_white
syn keyword col_dblue_wh	darkblue_on_white
syn keyword col_dgreen_wh	darkgreen_on_white
syn keyword col_dcyan_wh	darkcyan_on_white
syn keyword col_dred_wh	darkred_on_white
syn keyword col_dmagenta_wh	darkmagenta_on_white
syn keyword col_brown_wh	brown_on_white
syn keyword col_grey_wh	grey_on_white
syn keyword col_lgrey_wh	lightgrey_on_white
syn keyword col_dgrey_wh	darkgrey_on_white
syn keyword col_blue_wh	blue_on_white
syn keyword col_green_wh	green_on_white
syn keyword col_cyan_wh	cyan_on_white
syn keyword col_red_wh	red_on_white
syn keyword col_magenta_wh	magenta_on_white
syn keyword col_yellow_wh	yellow_on_white
syn keyword col_lblue_wh	lightblue_on_white
syn keyword col_lgreen_wh	lightgreen_on_white
syn keyword col_lcyan_wh	lightcyan_on_white
syn keyword col_lred_wh	lightred_on_white
syn keyword col_lmagenta_wh	lightmagenta_on_white
syn keyword col_dblue_bl	darkblue_on_black
syn keyword col_dgreen_bl	darkgreen_on_black
syn keyword col_dcyan_bl	darkcyan_on_black
syn keyword col_dred_bl	darkred_on_black
syn keyword col_dmagenta_bl	darkmagenta_on_black
syn keyword col_brown_bl	brown_on_black
syn keyword col_grey_bl	grey_on_black
syn keyword col_lgrey_bl	lightgrey_on_black
syn keyword col_dgrey_bl	darkgrey_on_black
syn keyword col_blue_bl	blue_on_black
syn keyword col_green_bl	green_on_black
syn keyword col_cyan_bl	cyan_on_black
syn keyword col_red_bl	red_on_black
syn keyword col_magenta_bl	magenta_on_black
syn keyword col_yellow_bl	yellow_on_black
syn keyword col_lblue_bl	lightblue_on_black
syn keyword col_lgreen_bl	lightgreen_on_black
syn keyword col_lcyan_bl	lightcyan_on_black
syn keyword col_lred_bl	lightred_on_black
syn keyword col_lmagenta_bl	lightmagenta_on_black

hi col_wh_bl	ctermfg=white	ctermbg=black	guifg=white	guibg=black
hi col_wh_dblue	ctermfg=white	ctermbg=darkblue	guifg=white	guibg=darkblue
hi col_wh_dgreen	ctermfg=white	ctermbg=darkgreen	guifg=white	guibg=darkgreen
hi col_wh_dcyan	ctermfg=white	ctermbg=darkcyan	guifg=white	guibg=darkcyan
hi col_wh_dred	ctermfg=white	ctermbg=darkred	guifg=white	guibg=darkred
hi col_wh_dmagenta	ctermfg=white	ctermbg=darkmagenta	guifg=white	guibg=darkmagenta
hi col_wh_brown	ctermfg=white	ctermbg=brown	guifg=white	guibg=brown
hi col_wh_grey	ctermfg=white	ctermbg=grey	guifg=white	guibg=grey
hi col_wh_lgrey	ctermfg=white	ctermbg=lightgrey	guifg=white	guibg=lightgrey
hi col_wh_dgrey	ctermfg=white	ctermbg=darkgrey	guifg=white	guibg=darkgrey
hi col_wh_blue	ctermfg=white	ctermbg=blue	guifg=white	guibg=blue
hi col_wh_green	ctermfg=white	ctermbg=green	guifg=white	guibg=green
hi col_wh_cyan	ctermfg=white	ctermbg=cyan	guifg=white	guibg=cyan
hi col_wh_red	ctermfg=white	ctermbg=red	guifg=white	guibg=red
hi col_wh_magenta	ctermfg=white	ctermbg=magenta	guifg=white	guibg=magenta
hi col_wh_yellow	ctermfg=white	ctermbg=yellow	guifg=white	guibg=yellow
hi col_wh_lblue	ctermfg=white	ctermbg=lightblue	guifg=white	guibg=lightblue
hi col_wh_lgreen	ctermfg=white	ctermbg=lightgreen	guifg=white	guibg=lightgreen
hi col_wh_lcyan	ctermfg=white	ctermbg=lightcyan	guifg=white	guibg=lightcyan
hi col_wh_lred	ctermfg=white	ctermbg=lightred	guifg=white	guibg=lightred
hi col_wh_lmagenta	ctermfg=white	ctermbg=lightmagenta	guifg=white	guibg=lightmagenta
hi col_wh_wh	ctermfg=white	ctermbg=white	guifg=white	guibg=white
hi col_bl_bl	ctermfg=black	ctermbg=black	guifg=black	guibg=black
hi col_bl_dblue	ctermfg=black	ctermbg=darkblue	guifg=black	guibg=darkblue
hi col_bl_dgreen	ctermfg=black	ctermbg=darkgreen	guifg=black	guibg=darkgreen
hi col_bl_dcyan	ctermfg=black	ctermbg=darkcyan	guifg=black	guibg=darkcyan
hi col_bl_dred	ctermfg=black	ctermbg=darkred	guifg=black	guibg=darkred
hi col_bl_dmagenta	ctermfg=black	ctermbg=darkmagenta	guifg=black	guibg=darkmagenta
hi col_bl_brown	ctermfg=black	ctermbg=brown	guifg=black	guibg=brown
hi col_bl_grey	ctermfg=black	ctermbg=grey	guifg=black	guibg=grey
hi col_bl_lgrey	ctermfg=black	ctermbg=lightgrey	guifg=black	guibg=lightgrey
hi col_bl_dgrey	ctermfg=black	ctermbg=darkgrey	guifg=black	guibg=darkgrey
hi col_bl_blue	ctermfg=black	ctermbg=blue	guifg=black	guibg=blue
hi col_bl_green	ctermfg=black	ctermbg=green	guifg=black	guibg=green
hi col_bl_cyan	ctermfg=black	ctermbg=cyan	guifg=black	guibg=cyan
hi col_bl_red	ctermfg=black	ctermbg=red	guifg=black	guibg=red
hi col_bl_magenta	ctermfg=black	ctermbg=magenta	guifg=black	guibg=magenta
hi col_bl_yellow	ctermfg=black	ctermbg=yellow	guifg=black	guibg=yellow
hi col_bl_lblue	ctermfg=black	ctermbg=lightblue	guifg=black	guibg=lightblue
hi col_bl_lgreen	ctermfg=black	ctermbg=lightgreen	guifg=black	guibg=lightgreen
hi col_bl_lcyan	ctermfg=black	ctermbg=lightcyan	guifg=black	guibg=lightcyan
hi col_bl_lred	ctermfg=black	ctermbg=lightred	guifg=black	guibg=lightred
hi col_bl_lmagenta	ctermfg=black	ctermbg=lightmagenta	guifg=black	guibg=lightmagenta
hi col_bl_wh	ctermfg=black	ctermbg=white	guifg=black	guibg=white
hi col_dblue_wh	ctermfg=darkblue	ctermbg=white	guifg=darkblue	guibg=white
hi col_dgreen_wh	ctermfg=darkgreen	ctermbg=white	guifg=darkgreen	guibg=white
hi col_dcyan_wh	ctermfg=darkcyan	ctermbg=white	guifg=darkcyan	guibg=white
hi col_dred_wh	ctermfg=darkred	ctermbg=white	guifg=darkred	guibg=white
hi col_dmagenta_wh	ctermfg=darkmagenta	ctermbg=white	guifg=darkmagenta	guibg=white
hi col_brown_wh	ctermfg=brown	ctermbg=white	guifg=brown	guibg=white
hi col_grey_wh	ctermfg=grey	ctermbg=white	guifg=grey	guibg=white
hi col_lgrey_wh	ctermfg=lightgrey	ctermbg=white	guifg=lightgrey	guibg=white
hi col_dgrey_wh	ctermfg=darkgrey	ctermbg=white	guifg=darkgrey	guibg=white
hi col_blue_wh	ctermfg=blue	ctermbg=white	guifg=blue	guibg=white
hi col_green_wh	ctermfg=green	ctermbg=white	guifg=green	guibg=white
hi col_cyan_wh	ctermfg=cyan	ctermbg=white	guifg=cyan	guibg=white
hi col_red_wh	ctermfg=red	ctermbg=white	guifg=red	guibg=white
hi col_magenta_wh	ctermfg=magenta	ctermbg=white	guifg=magenta	guibg=white
hi col_yellow_wh	ctermfg=yellow	ctermbg=white	guifg=yellow	guibg=white
hi col_lblue_wh	ctermfg=lightblue	ctermbg=white	guifg=lightblue	guibg=white
hi col_lgreen_wh	ctermfg=lightgreen	ctermbg=white	guifg=lightgreen	guibg=white
hi col_lcyan_wh	ctermfg=lightcyan	ctermbg=white	guifg=lightcyan	guibg=white
hi col_lred_wh	ctermfg=lightred	ctermbg=white	guifg=lightred	guibg=white
hi col_lmagenta_wh	ctermfg=lightmagenta	ctermbg=white	guifg=lightmagenta	guibg=white
hi col_dblue_bl	ctermfg=darkblue	ctermbg=black	guifg=darkblue	guibg=black
hi col_dgreen_bl	ctermfg=darkgreen	ctermbg=black	guifg=darkgreen	guibg=black
hi col_dcyan_bl	ctermfg=darkcyan	ctermbg=black	guifg=darkcyan	guibg=black
hi col_dred_bl	ctermfg=darkred	ctermbg=black	guifg=darkred	guibg=black
hi col_dmagenta_bl	ctermfg=darkmagenta	ctermbg=black	guifg=darkmagenta	guibg=black
hi col_brown_bl	ctermfg=brown	ctermbg=black	guifg=brown	guibg=black
hi col_grey_bl	ctermfg=grey	ctermbg=black	guifg=grey	guibg=black
hi col_lgrey_bl	ctermfg=lightgrey	ctermbg=black	guifg=lightgrey	guibg=black
hi col_dgrey_bl	ctermfg=darkgrey	ctermbg=black	guifg=darkgrey	guibg=black
hi col_blue_bl	ctermfg=blue	ctermbg=black	guifg=blue	guibg=black
hi col_green_bl	ctermfg=green	ctermbg=black	guifg=green	guibg=black
hi col_cyan_bl	ctermfg=cyan	ctermbg=black	guifg=cyan	guibg=black
hi col_red_bl	ctermfg=red	ctermbg=black	guifg=red	guibg=black
hi col_magenta_bl	ctermfg=magenta	ctermbg=black	guifg=magenta	guibg=black
hi col_yellow_bl	ctermfg=yellow	ctermbg=black	guifg=yellow	guibg=black
hi col_lblue_bl	ctermfg=lightblue	ctermbg=black	guifg=lightblue	guibg=black
hi col_lgreen_bl	ctermfg=lightgreen	ctermbg=black	guifg=lightgreen	guibg=black
hi col_lcyan_bl	ctermfg=lightcyan	ctermbg=black	guifg=lightcyan	guibg=black
hi col_lred_bl	ctermfg=lightred	ctermbg=black	guifg=lightred	guibg=black
hi col_lmagenta_bl	ctermfg=lightmagenta	ctermbg=black	guifg=lightmagenta	guibg=black

" vim:ts=21
